modifications to align with multiple version paradigm
diff --git a/buildNightlyList.sh b/buildNightlyList.sh
index 3ec9c9a..8bc9848 100644
--- a/buildNightlyList.sh
+++ b/buildNightlyList.sh
@@ -7,11 +7,10 @@
 BaseDownloadURL="http://www.eclipse.org/downloads/download.php?file=/rt/eclipselink/nightly"
 BaseDisplayURL="http://download.eclipse.org/rt/eclipselink/nightly"
 BaseDownloadNFSDir="/home/data/httpd/download.eclipse.org/rt/eclipselink"
-curdir=`pwd`
 buildir=/shared/rt/eclipselink
 cd ${buildir}
 
-echo "generating webpage"
+echo "generating webpage..."
 
 # safe temp directory
 tmp=${TMPDIR-/tmp}
@@ -21,6 +20,8 @@
   exit 1
 }
 
+cd ${BaseDownloadNFSDir}/nightly
+
 # Generate the nightly build table
 #    Dump out the table header html
 echo "<?xml version=\"1.0\" encoding=\"UTF-8\"?>                                   " >> $tmp/index.xml
@@ -28,75 +29,83 @@
 echo "    <description>                                                            " >> $tmp/index.xml
 echo "      <p> Automated builds and the corresponding Javadocs are created every Sunday - Thursday and are made available for download.  The process is kicked off shortly after midnight Eastern Time.</p>" >> $tmp/index.xml
 echo "    </description>                                                           " >> $tmp/index.xml
-echo "  <section class=\"main\" name=\"1.0 Nightly Builds (Incubation)\">          " >> $tmp/index.xml
+echo "  <section class=\"main\" name=\"Nightly Builds\">                           " >> $tmp/index.xml
 echo "    <description>                                                            " >> $tmp/index.xml
 echo "      <p>                                                                    " >> $tmp/index.xml
-echo "        <table border=\"1\">                                                 " >> $tmp/index.xml
-echo "          <tr>                                                               " >> $tmp/index.xml
-echo "            <th align=\"center\"> Build ID </th>                             " >> $tmp/index.xml
-echo "            <th align=\"center\"> Archives </th>                             " >> $tmp/index.xml
-echo "            <th align=\"center\"> </th>                                      " >> $tmp/index.xml
-echo "            <th colspan=\"5\" align=\"center\"> Nightly Testing Results </th>" >> $tmp/index.xml
-echo "          </tr>                                                              " >> $tmp/index.xml
 
-#    Generate each table row depending upon available content
-cd ${BaseDownloadNFSDir}/nightly
-for contentdir in `ls -dr [0-9]*` ; do
-    echo "          <tr>"  >> $tmp/index.xml
-    echo "            <td align=\"center\"> ${contentdir} </td>" >> $tmp/index.xml
-    echo "            <td align=\"center\">" >> $tmp/index.xml
-    if [ -f ${contentdir}/eclipselink-incubation-${contentdir}.zip ] ; then
-        echo "              <a href=\"${BaseDownloadURL}/${contentdir}/eclipselink-incubation-${contentdir}.zip\"> Install Archive </a> <br/>" >> $tmp/index.xml
-    else
-        echo "              Install archive not available <br/>" >> $tmp/index.xml
-    fi
-    if [ -f ${contentdir}/eclipselink-incubation-src-${contentdir}.zip ] ; then
-        echo "              <a href=\"${BaseDownloadURL}/${contentdir}/eclipselink-incubation-src-${contentdir}.zip\"> Source Archive </a> <br/>" >> $tmp/index.xml
-    else
-        echo "              Source archive not available <br/>" >> $tmp/index.xml
-    fi
-    if [ -f ${contentdir}/eclipselink-plugins-incubation-${contentdir}.zip ] ; then
-        echo "              <a href=\"${BaseDownloadURL}/${contentdir}/eclipselink-plugins-incubation-${contentdir}.zip\"> OSGi Plugins Archive </a> <br/>" >> $tmp/index.xml
-    else
-        echo "              OSGi Plugins archive not available <br/>" >> $tmp/index.xml
-    fi
-    echo "            </td>" >> $tmp/index.xml
-    echo "            <td align=\"center\"> </td>" >> $tmp/index.xml
-    if [ -f ${contentdir}/eclipselink-core-lrg-${contentdir}.html ] ; then
-        echo "            <td align=\"center\"> <a href=\"${BaseDisplayURL}/${contentdir}/eclipselink-core-lrg-${contentdir}.html\"> CoreLRG </a> </td>" >> $tmp/index.xml
-    else
-        if [ -f ${contentdir}/eclipselink-core-srg-${contentdir}.html ] ; then
-            echo "            <td align=\"center\"> <a href=\"${BaseDisplayURL}/${contentdir}/eclipselink-core-srg-${contentdir}.html\"> CoreSRG </a> </td>" >> $tmp/index.xml
+curdir=`pwd`
+for version in `ls -dr [0-9]*` ; do
+    cd ${version}
+    echo "        <table border=\"1\">                                                 " >> $tmp/index.xml
+    echo "          <tr>                                                               " >> $tmp/index.xml
+    echo "            <th colspan=\"8\" align=\"center\"> ${version} Nightly Build Results </th>" >> $tmp/index.xml
+    echo "          </tr>                                                              " >> $tmp/index.xml
+    echo "          <tr>                                                               " >> $tmp/index.xml
+    echo "            <th align=\"center\"> Build ID </th>                             " >> $tmp/index.xml
+    echo "            <th align=\"center\"> Archives </th>                             " >> $tmp/index.xml
+    echo "            <th align=\"center\"> </th>                                      " >> $tmp/index.xml
+    echo "            <th colspan=\"5\" align=\"center\"> Nightly Testing Results </th>" >> $tmp/index.xml
+    echo "          </tr>                                                              " >> $tmp/index.xml
+    
+    #    Generate each table row depending upon available content
+    for contentdir in `ls -dr [0-9]*` ; do
+        echo "          <tr>"  >> $tmp/index.xml
+        echo "            <td align=\"center\"> ${contentdir} </td>" >> $tmp/index.xml
+        echo "            <td align=\"center\">" >> $tmp/index.xml
+        if [ -f ${contentdir}/eclipselink-incubation-${contentdir}.zip ] ; then
+            echo "              <a href=\"${BaseDownloadURL}/${version}/${contentdir}/eclipselink-incubation-${contentdir}.zip\"> Install Archive </a> <br/>" >> $tmp/index.xml
         else
-            echo "            <td align=\"center\"> Core </td>" >> $tmp/index.xml
+            echo "              Install archive not available <br/>" >> $tmp/index.xml
         fi
-    fi
-    if [ -f ${contentdir}/eclipselink-jpa-lrg-${contentdir}.html ] ; then
-        echo "            <td align=\"center\"> <a href=\"${BaseDisplayURL}/${contentdir}/eclipselink-jpa-lrg-${contentdir}.html\"> JPA </a> </td>" >> $tmp/index.xml
-    else
-        echo "            <td align=\"center\"> JPA </td>" >> $tmp/index.xml
-    fi
-    if [ -f ${contentdir}/eclipselink-jaxb-lrg-${contentdir}.html ] ; then
-        echo "            <td align=\"center\"> <a href=\"${BaseDisplayURL}/${contentdir}/eclipselink-jaxb-lrg-${contentdir}.html\"> Moxy (JAXB) </a> </td>" >> $tmp/index.xml
-    else
-        echo "            <td align=\"center\"> Moxy (JAXB) </td>" >> $tmp/index.xml
-    fi
-    if [ -f ${contentdir}/eclipselink-oxm-lrg-${contentdir}.html ] ; then
-        echo "            <td align=\"center\"> <a href=\"${BaseDisplayURL}/${contentdir}/eclipselink-oxm-lrg-${contentdir}.html\"> Moxy (OXM) </a> </td>" >> $tmp/index.xml
-    else
-        echo "            <td align=\"center\"> Moxy (OXM) </td>" >> $tmp/index.xml
-    fi
-    if [ -f ${contentdir}/eclipselink-sdo-lrg-${contentdir}.html ] ; then
-        echo "            <td align=\"center\"> <a href=\"${BaseDisplayURL}/${contentdir}/eclipselink-sdo-lrg-${contentdir}.html\"> SDO </a> </td>" >> $tmp/index.xml
-    else
-        echo "            <td align=\"center\"> SDO </td>" >> $tmp/index.xml
-    fi
-    echo "          </tr>" >> $tmp/index.xml
+        if [ -f ${contentdir}/eclipselink-incubation-src-${contentdir}.zip ] ; then
+            echo "              <a href=\"${BaseDownloadURL}/${version}/${contentdir}/eclipselink-incubation-src-${contentdir}.zip\"> Source Archive </a> <br/>" >> $tmp/index.xml
+        else
+            echo "              Source archive not available <br/>" >> $tmp/index.xml
+        fi
+        if [ -f ${contentdir}/eclipselink-plugins-incubation-${contentdir}.zip ] ; then
+            echo "              <a href=\"${BaseDownloadURL}/${version}/${contentdir}/eclipselink-plugins-incubation-${contentdir}.zip\"> OSGi Plugins Archive </a> <br/>" >> $tmp/index.xml
+        else
+            echo "              OSGi Plugins archive not available <br/>" >> $tmp/index.xml
+        fi
+        echo "            </td>" >> $tmp/index.xml
+        echo "            <td align=\"center\"> </td>" >> $tmp/index.xml
+        if [ -f ${contentdir}/eclipselink-core-lrg-${contentdir}.html ] ; then
+            echo "            <td align=\"center\"> <a href=\"${BaseDisplayURL}/${version}/${contentdir}/eclipselink-core-lrg-${contentdir}.html\"> CoreLRG </a> </td>" >> $tmp/index.xml
+        else
+            if [ -f ${contentdir}/eclipselink-core-srg-${contentdir}.html ] ; then
+                echo "            <td align=\"center\"> <a href=\"${BaseDisplayURL}/${version}/${contentdir}/eclipselink-core-srg-${contentdir}.html\"> CoreSRG </a> </td>" >> $tmp/index.xml
+            else
+                echo "            <td align=\"center\"> Core </td>" >> $tmp/index.xml
+            fi
+        fi
+        if [ -f ${contentdir}/eclipselink-jpa-lrg-${contentdir}.html ] ; then
+            echo "            <td align=\"center\"> <a href=\"${BaseDisplayURL}/${version}/${contentdir}/eclipselink-jpa-lrg-${contentdir}.html\"> JPA </a> </td>" >> $tmp/index.xml
+        else
+            echo "            <td align=\"center\"> JPA </td>" >> $tmp/index.xml
+        fi
+        if [ -f ${contentdir}/eclipselink-jaxb-lrg-${contentdir}.html ] ; then
+            echo "            <td align=\"center\"> <a href=\"${BaseDisplayURL}/${version}/${contentdir}/eclipselink-jaxb-lrg-${contentdir}.html\"> Moxy (JAXB) </a> </td>" >> $tmp/index.xml
+        else
+            echo "            <td align=\"center\"> Moxy (JAXB) </td>" >> $tmp/index.xml
+        fi
+        if [ -f ${contentdir}/eclipselink-oxm-lrg-${contentdir}.html ] ; then
+            echo "            <td align=\"center\"> <a href=\"${BaseDisplayURL}/${version}/${contentdir}/eclipselink-oxm-lrg-${contentdir}.html\"> Moxy (OXM) </a> </td>" >> $tmp/index.xml
+        else
+            echo "            <td align=\"center\"> Moxy (OXM) </td>" >> $tmp/index.xml
+        fi
+        if [ -f ${contentdir}/eclipselink-sdo-lrg-${contentdir}.html ] ; then
+            echo "            <td align=\"center\"> <a href=\"${BaseDisplayURL}/${version}/${contentdir}/eclipselink-sdo-lrg-${contentdir}.html\"> SDO </a> </td>" >> $tmp/index.xml
+        else
+            echo "            <td align=\"center\"> SDO </td>" >> $tmp/index.xml
+        fi
+        echo "          </tr>" >> $tmp/index.xml
+    done
+    echo "        </table>                                                                          " >> $tmp/index.xml
+    echo "      </p>
+    cd ${curdir}                                                                                " >> $tmp/index.xml
 done
 
 # Dump the static footer into place
-echo "        </table>                                                                          " >> $tmp/index.xml
-echo "      </p>                                                                                " >> $tmp/index.xml
 echo "      <script src=\"http://www.google-analytics.com/urchin.js\" type=\"text/javascript\"/>" >> $tmp/index.xml
 echo "      <script type=\"text/javascript\">                                                   " >> $tmp/index.xml
 echo "        _uacct = \"UA-1608008-2\";                                                        " >> $tmp/index.xml
diff --git a/cleanNightly.sh b/cleanNightly.sh
index 1feb8e7..8af39bf 100644
--- a/cleanNightly.sh
+++ b/cleanNightly.sh
@@ -1,15 +1,17 @@
 # !/bin/sh
 set -x
 
+
+version=1.0
 BaseDownloadNFSDir="/home/data/httpd/download.eclipse.org/rt/eclipselink"
 buildir=/shared/rt/eclipselink
 
 cd ${buildir}
 num_files=10
 
 # leave only the last 10 build dirs on the download server
 index=0
-for contentdir in `ls -dr ${BaseDownloadNFSDir}/nightly/[0-9]*` ; do
+for contentdir in `ls -dr ${BaseDownloadNFSDir}/nightly/${version}/[0-9]*` ; do
     index=`expr $index + 1`
     if [ $index -gt $num_files ] ; then
         rm -r $contentdir
@@ -20,7 +22,7 @@
 index=0
 # 5 days worth of files - 9 files per day
 num_files=45
-for mvnfile in `ls -r ${BaseDownloadNFSDir}/maven.repo/org/eclipse/persistence/eclipselink/1.0-SNAPSHOT/eclipse*.* ` ; do
+for mvnfile in `ls -r ${BaseDownloadNFSDir}/maven.repo/org/eclipse/persistence/eclipselink/${version}-SNAPSHOT/eclipse*.* ` ; do
         index=`expr $index + 1`
         if [ $index -gt $num_files ] ; then
            rm $mvnfile
@@ -1,15 +1,17 @@
 num_files=10
 
-# leave only the last 10 build dirs on the download server
+# leave only the last 10 build dirs for the version on the download server
 index=0